@@ -5,7 +5,7 @@ use strict;
 use Carp;
 use Git;
 
-use version; our $VERSION = qv('0.0.4');
+use version; our $VERSION = qv('0.0.5');
 
 # Other recommended modules (uncomment to use):
 #  use IO::Prompt;
@@ -34,7 +34,8 @@ sub new {
   }
   my $commits = { _repo => $dir,
 		  _name => $repo_name,
-		  _commits => \@commit_info };
+		  _commits => \@commit_info,
+		  _hashes => \@these_revs};
   return bless $commits, $class;
 
 }
@@ -44,6 +45,11 @@ sub commits {
   return $self->{'_commits'};
 }
 
+sub hashes {
+  my $self = shift;
+  return $self->{'_hashes'};
+}
+
 sub name {
   my $self = shift;
   return $self->{'_name'};
@@ -85,95 +91,38 @@ the shape
       committer => $committer,
       files => \@files }
 
+=head2 hashes
+
+Returns an array with the hashes of all commits in the repo.
 
 =head2 name
 
 Returns the name of the directory, which usually is also the name of the repo. 
 
 
-=head1 INTERFACE 
-
-=for author to fill in:
-    Write a separate section listing the public components of the modules
-    interface. These normally consist of either subroutines that may be
-    exported, or methods that may be called on objects belonging to the
-    classes provided by the module.
-
-
-=head1 DIAGNOSTICS
-
-=for author to fill in:
-    List every single error and warning message that the module can
-    generate (even the ones that will "never happen"), with a full
-    explanation of each problem, one or more likely causes, and any
-    suggested remedies.
-
-=over
-
-=item C<< Error message here, perhaps with %s placeholders >>
-
-[Description of error here]
-
-=item C<< Another error message here >>
-
-[Description of error here]
-
-[Et cetera, et cetera]
-
-=back
-
-
 =head1 CONFIGURATION AND ENVIRONMENT
 
-=for author to fill in:
-    A full explanation of any configuration system(s) used by the
-    module, including the names and locations of any configuration
-    files, and the meaning of any environment variables or properties
-    that can be set. These descriptions must also include details of any
-    configuration language used.
-  
-Git::Repo::Commits requires no configuration files or environment variables.
+Git::Repo::Commits requires no configuration files or environment
+variables. It might be the case that git is not installed and this
+fails, but probably not. 
 
 
 =head1 DEPENDENCIES
 
-=for author to fill in:
-    A list of all the other modules that this module relies upon,
-    including any restrictions on versions, and an indication whether
-    the module is part of the standard Perl distribution, part of the
-    module's distribution, or must be installed separately. ]
-
-None.
+Depends on L<Git>, which should be available either from your git
+installation or from CPAN.
 
 
-=head1 INCOMPATIBILITIES
-
-=for author to fill in:
-    A list of any modules that this module cannot be used in conjunction
-    with. This may be due to name conflicts in the interface, or
-    competition for system or program resources, or due to internal
-    limitations of Perl (for example, many modules that use source code
-    filters are mutually incompatible).
-
-None reported.
 
 
 =head1 BUGS AND LIMITATIONS
 
-=for author to fill in:
-    A list of known problems with the module, together with some
-    indication Whether they are likely to be fixed in an upcoming
-    release. Also a list of restrictions on the features the module
-    does provide: data types that cannot be handled, performance issues
-    and the circumstances in which they may arise, practical
-    limitations on the size of data sets, special cases that are not
-    (yet) handled, etc.
-
 No bugs have been reported.
 
 Please report any bugs or feature requests to
 C<bug-git-repo-commits@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
+L<http://rt.cpan.org>, or, even better, at the
+L<https://github.com/JJ/perl-git-commit/issues> in GitHub.
 
 
 =head1 AUTHOR
